@@ -1,10 +1,8 @@
 from DetaCache._detaCache import detaCache
-from DetaCache._localCache import localCache
 from DetaCache._cacheApi import CacheApi
 
-__version__ ='v0.0.3'
+__version__ ='v0.0.5'
 __all__=[
     'detaCache',
-    'localCache',
     'CacheApi'
 ]
\ No newline at end of file
